==> pyloadl-0.0.1a4.tar.bz2: pyloadl-0.0.1a4/examples/rss.py <==

# Sample raw RSS file generator, this works quite nicely
# with the KNewsticker in KDE (www.kde.org) - for which I 
# generally found best to set the number of recent items 
# to 1 for the purpose of this feed.

from pyloadl import *

StepState=( "I", "P", "ST", "R",
    "CP", "XP", "RP",
    "VP", "C", "X", "RM",
    "V", "CA", "NR", "TX",
    "?", "SX", "H", "D",
    "NQ", "E", "EP",
    "MP")

link = "http://www/LoadL.html"

jobs_idle = 0
jobs_run  = 0
jobs_held = 0
jobs_not_queued = 0

# Query Job Status information

query = ll_query(JOBS)
rc = ll_set_request(query, QUERY_ALL, "", ALL_DATA)

if ( rc != 0 ):
	print "ll_set_request failed Return = %d" % rc

# Query the scheduler for information

job, number, err = ll_get_objs(query, LL_CM, NULL)
while PyCObjValid( job ):

	# Get the status for the first step of that Job

	step = ll_get_data(job, LL_JobGetFirstStep)
	state = ll_get_data(step, LL_StepState)
	st = StepState[state]

	if ( st == "R" ):	jobs_run = jobs_run + 1
	if ( st == "I" ):	jobs_idle = jobs_idle + 1
	if ( st == "H" ):	jobs_held = jobs_held + 1
	if ( st == "NQ" ):	jobs_not_queued = jobs_not_queued + 1

	job = ll_next_obj(query)

# Free up space allocated by LoadLeveler

ll_free_objs(job)
ll_deallocate(query)

title_string = "Jobs: R=jobs_run, I=jobs_idle, H=jobs_held, NQ=jobs_not_queued"

nodes_busy = 0
nodes_idle = 0
nodes_running = 0
nodes_down = 0

# Query Job Status information

query = ll_query(MACHINES)
rc = ll_set_request(query, QUERY_ALL, "", ALL_DATA)

if (rc != 0 )
	print "ll_set_request failed Return = %d" % rc

# Query the central manager for information
# number will contain the number of objects returned

machine, number, err = ll_get_objs(query, LL_CM, ALL_DATA)
while PyCObjValid( machine ):
   
	# Get the startd status for each machine

	sts = ll_get_data(machine, LL_MachineStartdState)

	if ( sts == "Busy" ):		nodes_busy = nodes_busy + 1
	if ( sts == "Idle" ):		nodes_idle = nodes_idle + 1
	if ( sts == "Running" ):	nodes_running = nodes_running + 1
	if ( sts == "Down" ):		nodes_down = nodes_down + 1

	machine = ll_next_obj(query)

# Free up space allocated by LoadLeveler

ll_free_objs(machine)
ll_deallocate(query)

title_string .= ". Nodes: B=nodes_busy, R=nodes_running, I=nodes_idle, D=nodes_down"

open (RDF,">loadl.rdf")
print RDF  "<?xml version=\"1.0\"?>"
print RDF  "   <!DOCTYPE rss PUBLIC \"-//Netscape Communications//DTD RSS 0.91//EN\""
print RDF  "             \"http://my.netscape.com/publish/formats/rss-0.91.dtd\" >"
print RDF  "   <rss version=\"0.91\">"
print RDF  "   <channel>"
print RDF  "   <title>Cluster 1A</title>"
print RDF  "   <description>Cluster 1A Web Server </description>"
print RDF  "   <item>"
print RDF  "   <title>$title_string</title>"
print RDF  "   <link>http://host.domain/status.html</link>"
print RDF  "   </item>"
print RDF  "   </channel>"
print RDF  "</rss>"
close (RDF)

==> pyloadl-0.0.4.tar.bz2: pyloadl-0.0.4/examples/rss.py <==

# Sample raw RSS file generator, this works quite nicely
# with the KNewsticker in KDE (www.kde.org) - for which I 
# generally found best to set the number of recent items 
# to 1 for the purpose of this feed.

from pyloadl import *
from sys import exit 

StepState = ( "I", "P", "ST", "R",
    "CP", "XP", "RP",
    "VP", "C", "X", "RM",
    "V", "CA", "NR", "TX",
    "?", "SX", "H", "D",
    "NQ", "E", "EP",
    "MP" )

link = "http://www/LoadL.html"

jobs_idle = 0
jobs_run  = 0
jobs_held = 0
jobs_not_queued = 0

# Query Job Status information

query = ll_query(JOBS)
if not PyCObjValid( query ):
  print "ll_query(): returns NULL\n"
  exit(-1)

rc = ll_set_request(query, QUERY_ALL, "", ALL_DATA)
if ( rc != 0 ):
  print "ll_set_request failed Return = %d" % rc

# Query the scheduler for information

job, number, err = ll_get_objs(query, LL_CM, NULL)
while PyCObjValid( job ):

  # Get the status for the first step of that Job

  step = ll_get_data(job, LL_JobGetFirstStep)
  holdtype = ll_get_data(step, LL_StepHoldType)
  state = ll_get_data(step, LL_StepState)
  st = StepState[state]

  if ( st == "R" ):   jobs_run = jobs_run + 1
  if ( st == "I" ):   jobs_idle = jobs_idle + 1
  if ( st == "NQ" ):  jobs_not_queued = jobs_not_queued + 1
  if ( hold_type > 0 ):
    jobs_held = jobs_held + 1

  job = ll_next_obj(query)

# Free up space allocated by LoadLeveler

ll_free_objs(job)
ll_deallocate(query)

title_string = "Jobs: R=jobs_run, I=jobs_idle, H=jobs_held, NQ=jobs_not_queued"

nodes_busy = 0
nodes_idle = 0
nodes_running = 0
nodes_down = 0

# Query Job Status information

query = ll_query(MACHINES)
rc = ll_set_request(query, QUERY_ALL, "", ALL_DATA)

if (rc != 0 )
  print "ll_set_request failed Return = %d" % rc

# Query the central manager for information
# number will contain the number of objects returned

machine, number, err = ll_get_objs(query, LL_CM, ALL_DATA)
while PyCObjValid( machine ):
   
  # Get the startd status for each machine

  sts = ll_get_data(machine, LL_MachineStartdState)

  if ( sts == "Busy" ):      nodes_busy = nodes_busy + 1
  if ( sts == "Idle" ):      nodes_idle = nodes_idle + 1
  if ( sts == "Running" ):   nodes_running = nodes_running + 1
  if ( sts == "Down" ):      nodes_down = nodes_down + 1

  machine = ll_next_obj(query)

# Free up space allocated by LoadLeveler

ll_free_objs(machine)
ll_deallocate(query)

title_string .= ". Nodes: B=nodes_busy, R=nodes_running, I=nodes_idle, D=nodes_down"

open (RDF,">loadl.rdf")
print RDF  "<?xml version=\"1.0\"?>"
print RDF  "   <!DOCTYPE rss PUBLIC \"-//Netscape Communications//DTD RSS 0.91//EN\""
print RDF  "             \"http://my.netscape.com/publish/formats/rss-0.91.dtd\" >"
print RDF  "   <rss version=\"0.91\">"
print RDF  "   <channel>"
print RDF  "   <title>Cluster 1A</title>"
print RDF  "   <description>Cluster 1A Web Server </description>"
print RDF  "   <item>"
print RDF  "   <title>$title_string</title>"
print RDF  "   <link>http://host.domain/status.html</link>"
print RDF  "   </item>"
print RDF  "   </channel>"
print RDF  "</rss>"
close (RDF)
